@@ -4,7 +4,7 @@
  * QingLong.12-12-96
  */
 
-#  include "HTAnchor.h"
+#  include "WWWCore.h"
 #  include "display_types.h"
 
 
@@ -19,7 +19,7 @@ typedef enum
 typedef struct s_history
 {
  HistoryState state; 
- HTAnchor *anchor;
+ HTAnchor* anchor;
  char *tag;
  long y;
  char *title;
