@@ -269,31 +269,46 @@ static Context* NewContext(void)
 {
  Context* context_new;
 
- if ((context_new = (Context*)HT_CALLOC(1, sizeof (Context))) == NULL)
-   HT_OUTOFMEM("Context_new");
+ if ((context_new = (Context*)HT_CALLOC(1, sizeof (Context))))
+   {
+    context_new->history         = HTList_new();
+#if 1	/* 16-04-97 Juergen Ruehle <jr@falbala.informatik.uni-kiel.de> */
+    context_new->current_history = NewHistory();
+    context_new->history_pos     = -1;
+#endif
+    context_new->encodings       = HTList_new();
+    context_new->conversions     = HTList_new();
+   }
+  else
+   HT_OUTOFMEM("NewContext");
+
  return context_new;
 }
 
 
 static void DeleteContext(Context* thecontext)
 {
- if (thecontext == NULL) return;
+ if (thecontext)
+   {
+    HTList_delete(thecontext->conversions);
+    HTList_delete(thecontext->encodings);
 
- HTList_delete(thecontext->conversions);
- HTList_delete(thecontext->encodings);
+    /*
+     * What must one do to ``HTParentAnchor* home_anchor'' to free it?
+     */
 
-/*
- * What must one do to ``HTParentAnchor* home_anchor'' to free it?
- */
+    /*
+     * Free ``StyleSheet* style''? But how?!
+     */
 
-/*
- * Free ``StyleSheet* style''? But how?!
- */
+    /*
+     * How must one do free with that wart named ``History* current_history''?
+     */
 
-/*
- * How must one do free with that wart named ``History* current_history''?
- */
- HT_FREE(thecontext);
+    HTList_delete(thecontext->history);
+
+    HT_FREE(thecontext);
+   }
 }
 
 
@@ -1635,7 +1650,7 @@ int CloneSelf(void)
 
  /* now clone history file and close original */
 
- initialised = 0;  /* avoid X output until this is true! */
+ initialised = False;  /* avoid X output until this is true! */
 
 /*    XCloseDisplay(display); */ /* close connection for parent display */
 
@@ -2909,14 +2924,7 @@ int main(int argc, char **argv)
   * Initialize all the context fields, but `style' (needs `paper').
   */
  context = NewContext();
- context->history = HTList_new();
-#if 1	/* 16-04-97 Juergen Ruehle <jr@falbala.informatik.uni-kiel.de> */
- context->current_history = NewHistory();
- context->history_pos = -1;
-#endif
- context->conversions = HTList_new();
  HTFormat_setConversion(context->conversions);
- context->encodings = HTList_new();
 
  ArenaBridgeInit();
 
