@@ -2,12 +2,13 @@
  * Routines to setup execute other programs as children.
  */
 
+#include <ctype.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <limits.h>
 #include <signal.h>
 #include <stdarg.h>
-#include <ctype.h>
+#include <waitflags.h>
 
 #include "arena.h"
 #ifdef ARENA_DEBUG
@@ -1018,11 +1019,7 @@ int SpawnEventHandler(SPAWNChildInfo *child)
  /*
   * Suggested 14-10-97 by Steffen Zahn.
   */
-#if defined(LibWWW_version) && (LibWWW_version == 501)
  HTEventList_loop(CurrentDoc->request); /* libwww-5.1 API */
-# else
- HTEventrg_loop(CurrentDoc->request);   /* libwww-5.0 API */
-#endif
 
  return EXIT_SUCCESS;
 }
